@@ -46,6 +46,10 @@ from .config import (
     get_logger,
 )
 from .accessory import Accessory
+from .plugin import (
+    WechatyPlugin,
+    WechatyPluginOptions
+)
 from .wechaty import (
     Wechaty,
     WechatyOptions,
@@ -62,6 +66,8 @@ from .user import (
     UrlLink,
 )
 
+from .version import VERSION
+__version__ = VERSION
 
 __all__ = [
     'Accessory',
@@ -79,6 +85,9 @@ __all__ = [
     'Wechaty',
     'WechatyOptions',
 
+    'WechatyPlugin',
+    'WechatyPluginOptions',
+
     'MessageType',
     'MessagePayload',
 
